@@ -141,7 +141,8 @@ nautilus_burn_get_file_items (NautilusMenuProvider *provider,
 	g_free (scheme);
 	
 	mime_type = nautilus_file_info_get_mime_type (file);
-	if (strcmp (mime_type, "application/x-iso-image") != 0) {
+	if (strcmp (mime_type, "application/x-iso-image") != 0 &&
+	    strcmp (mime_type, "application/x-cd-image") != 0) {
 		g_free (mime_type);
 		return NULL;
 	}
