@@ -24,12 +24,12 @@
 
 #include "config.h"
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
 #include <sys/param.h>
 #include <sys/mount.h>
 #else
 #include <sys/vfs.h>
-#endif /* __FreeBSD__ */
+#endif /* __FreeBSD__ || __NetBSD__ || __OpenBSD__ */
 #include <sys/types.h>
 #include <sys/stat.h>
 #ifdef HAVE_STATVFS
@@ -52,7 +52,26 @@
 #include "mkdtemp.h"
 #endif
 
-extern gboolean is_audio (char *mime_type);
+struct mkisofs_output {
+	GMainLoop *loop;
+	int result;
+	int pid;
+	const char *filename;
+};
+
+static struct mkisofs_output *mkisofs_output_ptr;
+
+void
+make_iso_cancel (void)
+{
+	if (mkisofs_output_ptr)
+	{
+		kill (mkisofs_output_ptr->pid, SIGINT);
+		unlink (mkisofs_output_ptr->filename);
+
+		g_main_loop_quit (mkisofs_output_ptr->loop);
+	}
+}
 
 static void
 write_all (int fd, char *buf, int len)
@@ -420,13 +439,6 @@ create_graft_file (GnomeVFSURI *uri,
 	gnome_vfs_file_info_unref (info);
 }
 
-struct mkisofs_output {
-	GMainLoop *loop;
-	int result;
-	int pid;
-	const char *filename;
-};
-
 static gboolean  
 mkisofs_stdout_read (GIOChannel   *source,
 		     GIOCondition  condition,
@@ -475,17 +487,6 @@ mkisofs_stderr_read (GIOChannel   *source,
 	return TRUE;
 }
 
-static void
-cancel_mkisofs (gpointer data)
-{
-	struct mkisofs_output *mkisofs_output = data;
-
-	kill (mkisofs_output->pid, SIGINT);
-	unlink (mkisofs_output->filename);
-	
-	g_main_loop_quit (mkisofs_output->loop);
-}
-
 /**
  * Create an ISO image in filename from the data files in burn:///
  */
@@ -579,6 +580,7 @@ retry:
 	argv[i++] = "-print-size";
 	argv[i++] = NULL;
 
+	error = NULL;
 	if (!g_spawn_sync (NULL,
 			   (char **)argv,
 			   NULL,
@@ -587,7 +589,7 @@ retry:
 			   &stdout_data,
 			   &stderr_data,
 			   &exit_status,
-			   NULL)) {
+			   &error)) {
 		g_warning ("mkisofs command failed: %s\n", error->message);
 		g_error_free (error);
 		/* TODO: Better error handling */
@@ -697,8 +699,8 @@ retry:
 					     mkisofs_stderr_read,
 					     &mkisofs_output);
 		g_io_channel_unref (channel);
-		
-		cd_progress_set_cancel_func (cancel_mkisofs, FALSE, &mkisofs_output);
+
+		mkisofs_output_ptr = &mkisofs_output;
 		mkisofs_output.filename = filename;
 		
 		g_main_loop_run (mkisofs_output.loop);
@@ -707,8 +709,8 @@ retry:
 		g_source_remove (stdout_tag);
 		g_source_remove (stderr_tag);
 	}
-	cd_progress_set_cancel_func (NULL, FALSE, NULL);
-	
+	mkisofs_output_ptr = NULL;
+
  cleanup:
 	for (l = state.remove_files; l != NULL; l = l->next) {
 		remove ((char *)l->data);
@@ -725,43 +727,3 @@ retry:
 	return mkisofs_output.result;
 }
 
-/**
- * Build a GList* of Track pointers from the audio tracks in burn:///
- */
-GList *
-build_list_of_audio_tracks (void)
-{
-	GList *list;
-	GnomeVFSFileInfo *info;
-	GnomeVFSDirectoryHandle *handle;
-	GnomeVFSResult result;
-	char *backing;
-	
-	result = gnome_vfs_directory_open (&handle, "burn:///", GNOME_VFS_FILE_INFO_FOLLOW_LINKS | GNOME_VFS_FILE_INFO_GET_MIME_TYPE);
-	if (result != GNOME_VFS_OK) {
-		return 0;
-	}
-	
-	info = gnome_vfs_file_info_new ();
-
-	list = NULL;
-	while (TRUE) {
-		result = gnome_vfs_directory_read_next (handle, info);
-		if (result != GNOME_VFS_OK)
-			break;
-
-		if (is_audio (info->mime_type)) {
-			Track *track;
-			backing = get_backing_file (info->name);
-			track = g_new0 (Track, 1);
-			track->type = TRACK_TYPE_AUDIO;
-			track->contents.audio.filename = backing;
-			track->contents.audio.cdtext = NULL;
-			list = g_list_prepend (list, track);
-		}
-	}
-
-	gnome_vfs_directory_close (handle);
-	gnome_vfs_file_info_unref (info);
-	return g_list_reverse (list);
-}
