@@ -24,4 +24,5 @@
 
 int make_iso (const char *filename, const char *label,
 		gboolean warn_low_space, gboolean use_joliet);
-GList *build_list_of_audio_tracks (void);
+void make_iso_cancel (void);
+
