@@ -639,7 +639,7 @@ burn_cd (CDDrive *rec, const char *source_iso, const char *label, gboolean eject
 			gc = gconf_client_get_default ();
 			path = gconf_client_get_string (gc, "/apps/nautilus-cd-burner/temp_iso_dir", NULL);
 			g_object_unref (G_OBJECT (gc));
-			if (path == NULL || strcmp (path, "") == 0) {
+			if (path != NULL && path[0] != '\0') {
 				filename = g_build_filename (path, "image.iso.XXXXXX", NULL);
 				fd = mkstemp(filename);
 				close (fd);
@@ -916,7 +916,7 @@ init_dialog (GladeXML *xml, GtkWidget *dialog, GnomeVFSFileSize size, char *disc
 
 		/*
 		translators: see strftime man page for meaning of %b, %d and %Y
-		the maximum length for this field is 32 characters
+		the maximum length for this field is 32 bytes
 		*/
 		g_date_strftime (buf, sizeof (buf), _("Personal Data, %b %d, %Y"), now);
 
