@@ -29,9 +29,6 @@
 #include "cd-drive.h"
 #include "cd-recorder.h"
 
-extern gint build_list_of_music_arguments (char *uri, int *argc, const char **argv, int max_num_args);
-gboolean is_audio (char *mime_type);
-
 /* UI callbacks: */
 extern void cd_progress_set_text        (const char *text);
 extern void cd_progress_set_fraction    (double      fraction);
